@@ -22,7 +22,7 @@ DbConnection::~DbConnection() {
 void DbConnection::connect(const cpp11::sexp& host, const cpp11::sexp& user,
                            const cpp11::sexp& password, const cpp11::sexp& db,
                            unsigned int port, const cpp11::sexp& unix_socket,
-                           unsigned long client_flag, const cpp11::sexp& groups,
+                           unsigned long client_flag, const cpp11::sexp& group,
                            const cpp11::sexp& default_file,
                            const cpp11::sexp& ssl_key, const cpp11::sexp& ssl_cert,
                            const cpp11::sexp& ssl_ca, const cpp11::sexp& ssl_capath,
@@ -36,23 +36,54 @@ void DbConnection::connect(const cpp11::sexp& host, const cpp11::sexp& user,
   mysql_options(this->pConn_, MYSQL_OPT_LOCAL_INFILE, &local_infile);
   // Default to UTF-8
   mysql_options(this->pConn_, MYSQL_SET_CHARSET_NAME, "utf8mb4");
-  if (!Rf_isNull(groups))
+  if (!Rf_isNull(group))
     mysql_options(this->pConn_, MYSQL_READ_DEFAULT_GROUP,
-                  cpp11::as_cpp<std::string>(groups).c_str());
+                  cpp11::as_cpp<std::string>(group).c_str());
   if (!Rf_isNull(default_file))
     mysql_options(this->pConn_, MYSQL_READ_DEFAULT_FILE,
                   cpp11::as_cpp<std::string>(default_file).c_str());
 
-  if (!Rf_isNull(ssl_key) || !Rf_isNull(ssl_cert) || !Rf_isNull(ssl_ca) ||
-      !Rf_isNull(ssl_capath) || !Rf_isNull(ssl_cipher)) {
-    mysql_ssl_set(
-      this->pConn_,
-      Rf_isNull(ssl_key) ? NULL : cpp11::as_cpp<std::string>(ssl_key).c_str(),
-      Rf_isNull(ssl_cert) ? NULL : cpp11::as_cpp<std::string>(ssl_cert).c_str(),
-      Rf_isNull(ssl_ca) ? NULL : cpp11::as_cpp<std::string>(ssl_ca).c_str(),
-      Rf_isNull(ssl_capath) ? NULL : cpp11::as_cpp<std::string>(ssl_capath).c_str(),
-      Rf_isNull(ssl_cipher) ? NULL : cpp11::as_cpp<std::string>(ssl_cipher).c_str()
-    );
+  // Set SSL options
+  if (client_flag & CLIENT_SSL) {
+#if MYSQL_VERSION_ID >= 80000 && MYSQL_VERSION_ID < 100000
+    // MySQL 8.0 deprecated the enforce SSL flag in prefernce to defining an SSL MODE
+    unsigned int ssl_mode_ = SSL_MODE_REQUIRED;
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_MODE, &ssl_mode_);
+#else    
+    my_bool use_ssl_ = 1;
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_ENFORCE, &use_ssl_);
+#endif
+    // From MySQL manual: Do not set this option within an application program; it is set internally in the client library.
+    // Instead the application program should set mysql_options
+    client_flag &= ~CLIENT_SSL;
+  }
+  if (client_flag & CLIENT_SSL_VERIFY_SERVER_CERT) {
+#if MYSQL_VERSION_ID >= 80000 && MYSQL_VERSION_ID < 100000
+    // Note: in MySQL 8.0, there is only mode, so we "upgrade" the mode to verify identity.
+    // Also, MySQL 8.0 has the ability to just verify the server CA, but our interface doesn't define that.
+    // If that is the desired SSL mode, then configure that via a defaults file or group definition.
+    unsigned int ssl_mode_ = SSL_MODE_VERIFY_IDENTITY;
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_MODE, &ssl_mode_);
+#else    
+    my_bool verify_server_cert_ = 1;
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_VERIFY_SERVER_CERT, (void *)&verify_server_cert_);
+#endif
+    client_flag &= ~CLIENT_SSL_VERIFY_SERVER_CERT;
+  }
+  if (!Rf_isNull(ssl_key)) {
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_KEY,    cpp11::as_cpp<std::string>(ssl_key).c_str());
+  }
+  if (!Rf_isNull(ssl_cert)) {
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_CERT,   cpp11::as_cpp<std::string>(ssl_cert).c_str());
+  }
+  if (!Rf_isNull(ssl_ca)) {
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_CA,     cpp11::as_cpp<std::string>(ssl_ca).c_str());
+  }
+  if (!Rf_isNull(ssl_capath)) {
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_CAPATH, cpp11::as_cpp<std::string>(ssl_capath).c_str());
+  }
+  if (!Rf_isNull(ssl_cipher)) {
+    mysql_options(this->pConn_, MYSQL_OPT_SSL_CIPHER, cpp11::as_cpp<std::string>(ssl_cipher).c_str());
   }
   if (timeout > 0) {
     mysql_options(this->pConn_, MYSQL_OPT_CONNECT_TIMEOUT,
@@ -60,7 +91,7 @@ void DbConnection::connect(const cpp11::sexp& host, const cpp11::sexp& user,
   }
   if (reconnect) {
     my_bool reconnect_ = 1;
-    mysql_options(this->pConn_, MYSQL_OPT_RECONNECT, (void *)&reconnect_);
+    mysql_options(this->pConn_, MYSQL_OPT_RECONNECT, &reconnect_);
   }
 
   LOG_VERBOSE;
@@ -108,17 +139,24 @@ void DbConnection::check_connection() {
 
 cpp11::list DbConnection::info() {
   using namespace cpp11::literals;
+  const char *ssl_cipher = mysql_get_ssl_cipher(pConn_);
   return
     cpp11::list({
       "host"_nm = std::string(pConn_->host),
+      "port"_nm = (pConn_->port != 0) ? pConn_->port : NA_INTEGER,
       "username"_nm = std::string(pConn_->user),
       "dbname"_nm = std::string(pConn_->db ? pConn_->db : ""),
       "con.type"_nm = std::string(mysql_get_host_info(pConn_)),
+      "ssl.cipher"_nm = (ssl_cipher != NULL) ? cpp11::as_sexp(std::string(ssl_cipher)) : R_NilValue,
+      "client.version"_nm = std::string(mysql_get_client_info()),
+      "client.version.int"_nm = (int) mysql_get_client_version(),
       "db.version"_nm = std::string(mysql_get_server_info(pConn_)),
       "db.version.int"_nm = (int) mysql_get_server_version(pConn_),
-      "port"_nm = NA_INTEGER,
       "protocol.version"_nm = (int) mysql_get_proto_info(pConn_),
-      "thread.id"_nm = (int) mysql_thread_id(pConn_)
+      "thread.id"_nm = (int) mysql_thread_id(pConn_),
+      "client.flag"_nm = pConn_->client_flag,
+      "server.capabilities"_nm = pConn_->server_capabilities,
+      "status"_nm = (int) pConn_->status
     });
 }
 
